"""Utility constants and helpers for calgebra.

Time unit constants represent durations in seconds.
These are used throughout the API for consistent time representation.
"""

# Time unit constants (all values in seconds)
SECOND = 1
MINUTE = 60
HOUR = 3600
DAY = 86400
WEEK = 604800
MONTH = 2678400
YEAR = 31536000
